@@ -1,15 +1,16 @@
 
 ## Base Object Models
 from async_openai.schemas.completions import CompletionChoice, CompletionObject, CompletionResponse
+from async_openai.schemas.chat import ChatMessage, ChatChoice, ChatObject, ChatResponse
 from async_openai.schemas.edits import EditChoice, EditObject, EditResponse
 from async_openai.schemas.embeddings import EmbeddingData, EmbeddingObject, EmbeddingResponse
 # from async_openai.schemas.files import FileChoice, FileObject, FileResponse
 from async_openai.schemas.images import ImageData, ImageObject, ImageResponse
 from async_openai.schemas.models import ModelData, ModelObject, ModelResponse
 
-
 ## Route Models
 from async_openai.schemas.completions import CompletionRoute
+from async_openai.schemas.chat import ChatRoute
 from async_openai.schemas.edits import EditRoute
 from async_openai.schemas.embeddings import EmbeddingRoute
 # from async_openai.schemas.files import FileRoute
