@@ -1,10 +1,14 @@
-from typing import Optional, Type, Any, Union, List, Dict
+import aiohttpx
+import json
+
+from typing import Optional, Type, Any, Union, List, Dict, Iterator
 from lazyops.types import validator, lazyproperty
 
 from async_openai.types.options import OpenAIModel, OpenAIModelType
 from async_openai.types.resources import BaseResource
 from async_openai.types.responses import BaseResponse
 from async_openai.types.routes import BaseRoute
+from async_openai.utils import logger
 
 
 __all__ = [
@@ -41,10 +45,12 @@ class CompletionObject(BaseResource):
     user: Optional[str] = None
 
     @validator('model', pre=True, always=True)
-    def validate_model(cls, v) -> OpenAIModel:
+    def validate_model(cls, v, values: Dict[str, Any]) -> OpenAIModel:
         """
         Validate the model
         """
+        if not v and values.get('engine'):
+            v = values.get('engine')
         if isinstance(v, OpenAIModel):
             return v
         if isinstance(v, dict):
@@ -100,6 +106,18 @@ class CompletionObject(BaseResource):
         return None if v is None else max(0.0, min(v, 2.0))
     
 
+    def dict(self, *args, exclude: Any = None, **kwargs):
+        """
+        Returns the dict representation of the response
+        """
+        data = super().dict(*args, exclude = exclude, **kwargs)
+        if data.get('model'):
+            data['model'] = data['model'].value
+        return data
+
+
+    
+
 class CompletionResponse(BaseResponse):
     choices: Optional[List[CompletionChoice]]
     choice_model: Optional[Type[BaseResource]] = CompletionChoice
@@ -109,7 +127,7 @@ class CompletionResponse(BaseResponse):
         """
         Returns the text for the completions
         """
-        if self.choices:
+        if self.choices_results:
             return ''.join([choice.text for choice in self.choices])
         return self._response.text
     
@@ -130,6 +148,54 @@ class CompletionResponse(BaseResponse):
         return None
 
 
+    def dict(self, *args, exclude: Any = None, **kwargs):
+        """
+        Returns the dict representation of the response
+        """
+        data = super().dict(*args, exclude = exclude, **kwargs)
+        if data.get('completion_model'):
+            data['completion_model'] = data['completion_model'].dict()
+        return data
+
+
+    def handle_stream(
+        self,
+        response: aiohttpx.Response
+    ) -> Iterator[Dict]:
+        texts = {}
+        for line in response.iter_lines():
+            if not line: continue
+            if "data: [DONE]" in line:
+                continue
+            if line.startswith("data: "):
+                line = line[len("data: ") :]
+            if not line.strip(): continue
+            try:
+
+                item = json.loads(line)
+                self.handle_stream_metadata(item)
+                for n, choice in enumerate(item['choices']):
+                    if not texts.get(n):
+                        texts[n] = {
+                            'index': choice['index'],
+                            'text': choice['text'],
+                        }
+                        self.usage.completion_tokens += 1
+                    elif choice['finish_reason'] != 'stop':
+                        texts[n]['text'] += choice['text']
+                        self.usage.completion_tokens += 1
+
+                    else:
+                        texts[n]['finish_reason'] = choice['finish_reason']
+                        yield texts.pop(n)
+
+            except Exception as e:
+                logger.error(f'Error: {line}: {e}')
+
+        yield from texts.values()
+        self.usage.total_tokens = self.usage.completion_tokens
+
+
 class CompletionRoute(BaseRoute):
     input_model: Optional[Type[BaseResource]] = CompletionObject
     response_model: Optional[Type[BaseResource]] = CompletionResponse
